==> bibledit_1.7.orig.tar.gz: bibledit-1.7/src/dialogcompare.h <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGCOMPARE_H
#define INCLUDED_DIALOGCOMPARE_H

#include <gtk/gtk.h>
#include "configuration.h"
#include "ustring.h"
#include "usfm.h"


class CompareDialog
{
public:
  CompareDialog (Configuration * configuration);
  virtual ~CompareDialog ();
  virtual int run ();
protected:
  GtkWidget *comparedialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *label1;
  GtkWidget *combobox1;
  GtkWidget *checkbutton1;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton;
  GtkWidget *okbutton;
  static bool on_combobox1_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data);
  bool on_combobox1_key_press (GdkEventKey *event);
  static void static_on_okbutton_clicked (GtkButton * button, gpointer user_data);
  void on_okbutton_clicked ();
  Configuration * myconfiguration;
};


#endif

==> bibledit_1.9.orig.tar.gz: bibledit-1.9/src/dialogcompare.h <==
/*
** Copyright (C) 2003-2006 Teus Benschop.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_DIALOGCOMPARE_H
#define INCLUDED_DIALOGCOMPARE_H

#include <gtk/gtk.h>
#include "ustring.h"
#include "usfm.h"


class CompareDialog
{
public:
  CompareDialog (int dummy);
  ~CompareDialog ();
  int run ();
protected:
  GtkWidget *comparedialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *vbox1;
  GtkWidget *label1;
  GtkWidget *combobox1;
  GtkWidget *checkbutton1;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton;
  GtkWidget *okbutton;
  static bool on_combobox1_key_press_event (GtkWidget *widget, GdkEventKey *event, gpointer user_data);
  bool on_combobox1_key_press (GdkEventKey *event);
  static void static_on_okbutton_clicked (GtkButton * button, gpointer user_data);
  void on_okbutton_clicked ();
};


#endif
